==> v4.2.4.tar.gz: 2fauth/resources/lang/de/commons.php <==
<?php

return [

    /*
    |--------------------------------------------------------------------------
    | Authentication Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines are used during authentication for various
    | messages that we need to display to the user. You are free to modify
    | these language lines according to your application's requirements.
    |
    */

    'cancel' => 'Abbrechen',
    'update' => 'Aktualisieren',
    'copy' => 'Kopieren',
    'copy_to_clipboard' => 'In die Zwischenablage kopieren',
    'copied_to_clipboard' => 'In die Zwischenablage kopiert',
    'profile' => 'Profil',
    'edit' => 'Bearbeiten',
    'delete' => 'Löschen',
    'disable' => 'Deaktivieren',
    'enable' => 'Aktivieren',
    'create' => 'Erstellen',
    'save' => 'Speichern',
    'close' => 'Schließen',
    'clear' => 'Leeren',
    'clear_search' => 'Suche leeren',
    'demo_do_not_post_sensitive_data' => 'Dies ist eine Demo-App, veröffentlichen Sie keine sensiblen Daten',
    'testing_do_not_post_sensitive_data' => 'Dies ist eine Test-App, veröffentlichen Sie keine sensiblen Daten',
    'selected' => 'ausgewählt',
    'name' => 'Name',
    'manage' => 'Verwalten',
    'done' => 'Fertig',
    'new' => 'Neu',
    'back' => 'Zurück',
    'move' => 'Verschieben',
    'export' => 'Exportieren',
    'all' => 'Alle',
    'select_all' => 'Alle auswählen',
    'clear_selection' => 'Auswahl löschen',
    'sort_descending' => 'Sortierung absteigend',
    'sort_ascending' => 'Sortierung aufsteigend',
    'rename' => 'Umbenennen',
    'new_name' => 'Neu Name',
    'options' => 'Einstellungen',
    'reload' => 'Aktualisieren',
    'some_data_have_changed' => 'Einige Daten haben sich geändert. Sie sollten diese Seite',
    'generate' => 'Generieren',
    'generating_otp' => 'Generating OTP',
    'open_in_browser' => 'Im Browser öffnen',
    'continue' => 'Weiter',
    'discard' => 'Löschen',
    'about' => 'Über',
    'usefull_links' => 'Nützliche Links',
    'environment' => 'Umgebung',
    'credits' => 'Mitwirkende',
    '2fauth_teaser' => 'Eine Web-App um Ihre Zwei-Faktor-Authentifizierung (2FA) Konten zu verwalten und deren Sicherheitscodes zu generieren',
    'made_with' => 'Erstellt mit',
    'ui_icons_by' => 'UI-Icons von',
    'logos_by' => 'Logos von',
    'search' => 'Suche',
    'resources' => 'Ressourcen',
    'check_for_update' => 'Auf neue Version prüfen',
    'check_for_update_help' => 'Automatisch überprüfen (einmal pro Woche) und warnen, wenn eine neue Version von 2FAuth auf Github veröffentlicht wird',
    'you_are_up_to_date' => 'Instanz ist auf dem neusten Stand',
    '2fauth_description' => 'Eine Web-App um Ihre Zwei-Faktor-Authentifizierung (2FA) Konten zu verwalten und deren Sicherheitscodes zu generieren',
    'image_of_qrcode_to_scan' => 'Bild eines QR-Codes zum Scannen',
    'file' => 'Datei',
    'or' => 'ODER',
    'close_the_x_page' => '{pagetitle} Seite schließen',
];

==> v5.0.1.tar.gz: 2fauth/resources/lang/de/commons.php <==
<?php

return [

    /*
    |--------------------------------------------------------------------------
    | Authentication Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines are used during authentication for various
    | messages that we need to display to the user. You are free to modify
    | these language lines according to your application's requirements.
    |
    */

    'cancel' => 'Abbrechen',
    'update' => 'Aktualisieren',
    'copy' => 'Kopieren',
    'copy_to_clipboard' => 'In die Zwischenablage kopieren',
    'copied_to_clipboard' => 'In die Zwischenablage kopiert',
    'profile' => 'Profil',
    'edit' => 'Bearbeiten',
    'delete' => 'Löschen',
    'disable' => 'Deaktivieren',
    'enable' => 'Aktivieren',
    'create' => 'Erstellen',
    'save' => 'Speichern',
    'close' => 'Schließen',
    'clear' => 'Leeren',
    'clear_search' => 'Suche leeren',
    'demo_do_not_post_sensitive_data' => 'Dies ist eine Demo-App, veröffentlichen Sie keine sensiblen Daten',
    'testing_do_not_post_sensitive_data' => 'Dies ist eine Test-App, veröffentlichen Sie keine sensiblen Daten',
    'selected' => 'ausgewählt',
    'name' => 'Name',
    'manage' => 'Verwalten',
    'done' => 'Fertig',
    'new' => 'Neu',
    'back' => 'Zurück',
    'move' => 'Verschieben',
    'export' => 'Exportieren',
    'all' => 'Alle',
    'select_all' => 'Alle auswählen',
    'clear_selection' => 'Auswahl löschen',
    'sort_descending' => 'Sortierung absteigend',
    'sort_ascending' => 'Sortierung aufsteigend',
    'rename' => 'Umbenennen',
    'new_name' => 'Neu Name',
    'options' => 'Einstellungen',
    'reload' => 'Aktualisieren',
    'refresh' => 'Refresh',
    'data_refreshed_to_reflect_server_changes' => 'Data has been refresh to reflect server-side changes',
    'generate' => 'Generieren',
    'generating_otp' => 'Generiere OTP',
    'open_in_browser' => 'Im Browser öffnen',
    'continue' => 'Weiter',
    'discard' => 'Löschen',
    'about' => 'Über',
    'usefull_links' => 'Nützliche Links',
    'environment' => 'Umgebung',
    'credits' => 'Mitwirkende',
    '2fauth_teaser' => 'Eine Web-App um Ihre Zwei-Faktor-Authentifizierung (2FA) Konten zu verwalten und deren Sicherheitscodes zu generieren',
    'made_with' => 'Erstellt mit',
    'ui_icons_by' => 'UI-Icons von',
    'logos_by' => 'Logos von',
    'search' => 'Suche',
    'resources' => 'Ressourcen',
    'check_for_update' => 'Auf neue Version prüfen',
    'check_for_update_help' => 'Automatisch überprüfen (einmal pro Woche) und warnen, wenn eine neue Version von 2FAuth auf Github veröffentlicht wird',
    'you_are_up_to_date' => 'Instanz ist auf dem neusten Stand',
    '2fauth_description' => 'Eine Web-App um Ihre Zwei-Faktor-Authentifizierung (2FA) Konten zu verwalten und deren Sicherheitscodes zu generieren',
    'image_of_qrcode_to_scan' => 'Bild eines QR-Codes zum Scannen',
    'file' => 'Datei',
    'or' => 'ODER',
    'close_the_x_page' => '{pagetitle} Seite schließen',
    'submit' => 'Submit',
    'default' => 'Default',
    'back_to_home' => 'Back to home',
    'nothing' => 'nothing',
];
